aboutsummaryrefslogtreecommitdiffstats
path: root/include/functions_mail.inc.php
diff options
context:
space:
mode:
authorrub <rub@piwigo.org>2007-03-28 19:57:00 +0000
committerrub <rub@piwigo.org>2007-03-28 19:57:00 +0000
commit7c43a3c62d28162ee70e960f51e048727725cb31 (patch)
tree1b967195f4edf6db91bf25a6facda55ad08a8935 /include/functions_mail.inc.php
parentb86d4ac0b89e167bedbd03805e7c7024da5cef03 (diff)
Issue 578
User guest must be real user Step 1: guest is a real user On next commit, I finish installation and use of guest of user list and group git-svn-id: http://piwigo.org/svn/trunk@1926 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'include/functions_mail.inc.php')
-rw-r--r--include/functions_mail.inc.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/include/functions_mail.inc.php b/include/functions_mail.inc.php
index 5f10d2f0a..d7314fb82 100644
--- a/include/functions_mail.inc.php
+++ b/include/functions_mail.inc.php
@@ -93,12 +93,12 @@ function format_email($name, $email)
/**
* Returns an completed array template/theme
- * completed with $conf['default_template']
+ * completed with get_default_template()
*
* @params:
* - args: incompleted array of template/theme
* o template: template to use [default $conf['default_template']]
* o theme: template to use [default $conf['default_template']]
*/
function get_array_template_theme($args = array())
{
@@ -108,7 +108,7 @@ function get_array_template_theme($args = array())
if (empty($args['template']) or empty($args['theme']))
{
- list($res['template'], $res['theme']) = explode('/', $conf['default_template']);
+ list($res['template'], $res['theme']) = explode('/', get_default_template());
}
if (!empty($args['template']))
@@ -130,8 +130,8 @@ function get_array_template_theme($args = array())
* @params:
* - email_format: mail format
* - args: function params of mail function:
* o template: template to use [default $conf['default_template']]
* o theme: template to use [default $conf['default_template']]
*/
function get_mail_template($email_format, $args = array())
{
@@ -298,7 +298,7 @@ order by
get_l10n_args('Browser: %s', $_SERVER['HTTP_USER_AGENT'])
);
- switch_lang_to($conf['default_language']);
+ switch_lang_to(get_default_language());
$return = pwg_mail
(
@@ -451,8 +451,8 @@ WHERE
* o content: content of mail [default value '']
* o content_format: format of mail content [default value 'text/plain']
* o email_format: global mail format [default value $conf_mail['default_email_format']]
* o template: template to use [default $conf['default_template']]
* o theme: template to use [default $conf['default_template']]
*
* @return boolean (Ok or not)
*/
@@ -93,12 +93,12 @@ function format_email($name, $email)
* @params:
* - args: incompleted array of template/theme
- * o template: template to use [default $conf['default_template']]
- * o theme: template to use [default $conf['default_template']]
+ * o template: template to use [default get_default_template()]
+ * o theme: template to use [default get_default_template()]
*/
function get_array_template_theme($args = array())
@@ -130,8 +130,8 @@ function get_array_template_theme($args = array())
* - email_format: mail format
* - args: function params of mail function:
- * o template: template to use [default $conf['default_template']]
- * o theme: template to use [default $conf['default_template']]
+ * o template: template to use [default get_default_template()]
+ * o theme: template to use [default get_default_template()]
*/
function get_mail_template($email_format, $args = array())
@@ -451,8 +451,8 @@ WHERE
* o content_format: format of mail content [default value 'text/plain']
* o email_format: global mail format [default value $conf_mail['default_email_format']]
- * o template: template to use [default $conf['default_template']]
- * o theme: template to use [default $conf['default_template']]
+ * o template: template to use [default get_default_template()]
+ * o theme: template to use [default get_default_template()]
*
* @return boolean (Ok or not)